ArrayView

Struct ArrayView 

pub struct ArrayView<'a> { /* private fields */ }
A zero-copy view over an encoded ProtoCache array.

Implementations

Source

impl<'a> ArrayView<'a>

pub fn new(words: &'a [u32]) -> Option<Self>

Parses an encoded array from words.

pub fn detect_len(words: &'a [u32]) -> Option<usize>

Detects the complete encoded array length, including referenced items.

pub fn detect(words: &'a [u32]) -> Option<&'a [u32]>

Returns the exact encoded slice occupied by a valid array.

pub fn len(self) -> usize

Returns the number of array elements.

pub fn is_empty(self) -> bool

pub fn width(self) -> usize

pub fn field(self, index: usize) -> Option<FieldView<'a>>

Returns a raw field view for the element at index.

pub fn expect_field(self, index: usize) -> FieldView<'a>

pub fn scalars<T: Scalar>(self) -> Option<ScalarArray<'a, T>>

pub fn expect_scalars<T: Scalar>(self) -> ScalarArray<'a, T>

pub fn iter(self) -> ArrayIter<'a>