Module mutable

Module mutable 

Mutable containers and traits used by generated mutable bindings. Mutable surface matching access-ex.h.

Structs

MutableArray
An owned mutable array with dirty tracking for generated messages.
MutableMap
An owned mutable map with dirty tracking and ProtoCache key encoding.
MutableMessage
Lazy mutable state for a generated message.

Enums

MutableError
Error returned while decoding or serializing a generated mutable message.
MutableMapKeyKind
The wire-level key representation used by a mutable map.

Traits

MutableArrayElement
Array-specific extension of MutableField used by generated bindings.
MutableField
Encoding and dirty-tracking contract implemented by mutable field values.
MutableMapKey
Map-key encoding contract used by MutableMap.

Functions

copy_words
Copies an already encoded field into buffer, optionally folding small data into the returned Unit.