MutableArray

Struct MutableArray 

pub struct MutableArray<'a, T> { /* private fields */ }
An owned mutable array with dirty tracking for generated messages.

Implementations

Source

impl<'a, T> MutableArray<'a, T>

pub fn new() -> Self

Creates an empty, clean mutable array.

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn clear(&mut self)

Removes all values and marks the array dirty.

pub fn reserve(&mut self, additional: usize)

pub fn push(&mut self, value: T)

Appends a value and marks the array dirty.

pub fn as_slice(&self) -> &[T]

pub fn as_mut_slice(&mut self) -> &mut [T]

pub fn iter(&self) -> impl Iterator<Item = &T>

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>

Source

impl<'a, T: MutableArrayElement<'a>> MutableArray<'a, T>

pub fn from_words(words: &'a [u32]) -> Option<Self>

Decodes all elements from an encoded array.

pub fn encode_to_unit(&self, buffer: &mut Buffer) -> Result<Unit, MutableError>

Encodes the array into buffer and returns its field representation.