Mutable containers and traits used by generated mutable bindings.
Mutable surface matching access-ex.h.
Structs
- Mutable
Array - An owned mutable array with dirty tracking for generated messages.
- Mutable
Map - An owned mutable map with dirty tracking and ProtoCache key encoding.
- Mutable
Message - Lazy mutable state for a generated message.
Enums
- Mutable
Error - Error returned while decoding or serializing a generated mutable message.
- Mutable
MapKey Kind - The wire-level key representation used by a mutable map.
Traits
- Mutable
Array Element - Array-specific extension of
MutableFieldused by generated bindings. - Mutable
Field - Encoding and dirty-tracking contract implemented by mutable field values.
- Mutable
MapKey - Map-key encoding contract used by
MutableMap.
Functions
- copy_
words - Copies an already encoded field into
buffer, optionally folding small data into the returnedUnit.