pub struct MutableArray<'a, T> { /* private fields */ }Expand description
An owned mutable array with dirty tracking for generated messages.
Implementations
Sourceimpl<'a, T> MutableArray<'a, T>
impl<'a, T> MutableArray<'a, T>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn reserve(&mut self, additional: usize)
pub fn as_slice(&self) -> &[T]
pub fn as_mut_slice(&mut self) -> &mut [T]
pub fn iter(&self) -> impl Iterator<Item = &T>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>
Sourceimpl<'a, T: MutableArrayElement<'a>> MutableArray<'a, T>
impl<'a, T: MutableArrayElement<'a>> MutableArray<'a, T>
Sourcepub fn from_words(words: &'a [u32]) -> Option<Self>
pub fn from_words(words: &'a [u32]) -> Option<Self>
Decodes all elements from an encoded array.
Sourcepub fn encode_to_unit(&self, buffer: &mut Buffer) -> Result<Unit, MutableError>
pub fn encode_to_unit(&self, buffer: &mut Buffer) -> Result<Unit, MutableError>
Encodes the array into buffer and returns its field representation.