pub struct MutableMap<'a, K, V> { /* private fields */ }Expand description
An owned mutable map with dirty tracking and ProtoCache key encoding.
Implementations
Sourceimpl<'a, K: Eq + Hash, V> MutableMap<'a, K, V>
impl<'a, K: Eq + Hash, V> MutableMap<'a, K, V>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn reserve(&mut self, additional: usize)
Sourcepub fn insert(&mut self, key: K, value: V) -> Option<V>
pub fn insert(&mut self, key: K, value: V) -> Option<V>
Inserts an entry and marks the map dirty.
pub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn get<Q>(&self, key: &Q) -> Option<&V>
Sourcepub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
Returns mutable access to a value and marks the map dirty when found.
pub fn remove<Q>(&mut self, key: &Q) -> Option<V>
pub fn iter(&self) -> impl Iterator<Item = (&K, &V)>
Sourceimpl<'a, K: MutableMapKey<'a>, V: MutableField<'a>> MutableMap<'a, K, V>
impl<'a, K: MutableMapKey<'a>, V: MutableField<'a>> MutableMap<'a, K, V>
Sourcepub fn from_words(words: &'a [u32]) -> Option<Self>
pub fn from_words(words: &'a [u32]) -> Option<Self>
Decodes all entries from an encoded map.
Sourcepub fn encode_to_unit(&self, buffer: &mut Buffer) -> Result<Unit, MutableError>
pub fn encode_to_unit(&self, buffer: &mut Buffer) -> Result<Unit, MutableError>
Encodes the map and its perfect-hash index into buffer.