Shared scalar, buffer, compression, and error utilities.
Utility surface matching utils.h.
Structs
- Buffer
- Reusable reverse-growing word buffer used by ProtoCache encoders.
- Read
Error - Error returned when compressed input is malformed or incomplete.
Enums
- Corruption
Kind - Broad reason that encoded or compressed input could not be read.
Traits
- Scalar
- A fixed-width scalar that can be read from and written to little-endian words.
Functions
- compress
- Compresses bytes using ProtoCache’s lightweight run encoding.
- compress_
into - Compresses into
out, clearing its previous contents while reusing capacity. - decompress
- Decompresses data produced by
compress. - decompress_
into - Decompresses into
out, reusing its allocation. - load_
file - Reads an entire file into memory.
- word_
size - Converts a byte length to the number of four-byte ProtoCache words.